#
# spec file for package python-snimpy
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-snimpy
Version:        1.0.3
Release:        2.1
Summary:        Interactive SNMP tool
License:        ISC
URL:            https://github.com/vincentbernat/snimpy
Source:         https://files.pythonhosted.org/packages/source/s/snimpy/snimpy-%{version}.tar.gz
BuildRequires:  %{python_module cffi >= 1.0.0}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module vcversioner}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  libsmi-devel
BuildRequires:  python-rpm-macros
Requires:       python-cffi >= 1.0.0
Requires:       python-pysnmp >= 5
Requires:       python-setuptools
Requires:       (python-pyasyncore if python-base >= 3.12)
Requires(post): update-alternatives
Requires(postun): update-alternatives
# SECTION test requirements
BuildRequires:  %{python_module cffi >= 1.0.0}
BuildRequires:  %{python_module pyasyncore if %python-base >= 3.12}
BuildRequires:  %{python_module pysnmp >= 5}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Snimpy is a Python-based tool providing a simple interface to build
SNMP query. You can either use Snimpy interactively through its console
(derived from Python own console or from IPython_ if available) or write
Snimpy scripts which are just Python scripts with some global variables
available.

Snimpy is aimed at being the more Pythonic possible. You should forget
that you are doing SNMP requests. Snimpy will rely on MIB to hide SNMP
details. Here are some "features":

 * MIB parser based on libsmi  (through CFFI)
 * SNMP requests are handled by PySNMP (SNMPv1, SNMPv2 and SNMPv3
   support)
 * scalars are just attributes of your session object
 * columns are like a Python dictionary and made available as an
   attribute
 * getting an attribute is like issuing a GET method
 * setting an attribute is like issuing a SET method
 * iterating over a table is like using GETNEXT
 * when something goes wrong, you get an exception

%prep
%autosetup -p1 -n snimpy-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_clone -a %{buildroot}%{_bindir}/snimpy
%python_clone -a %{buildroot}%{_mandir}/man1/snimpy.1

%check
# too recent pyasn1, upstream pinned it in https://github.com/vincentbernat/snimpy/commit/f22d1994a9771858bb30ff3c0801a121e45c145b
# let's skip the affected test files for now: tests/test_main.py tests/test_manager.py tests/test_snmp.py
rm tests/test_main.py tests/test_manager.py tests/test_snmp.py
%pytest_arch

%post
%python_install_alternative snimpy snimpy.1

%postun
%python_uninstall_alternative snimpy snimpy.1

%files %{python_files}
%license docs/license.rst
%doc AUTHORS.rst README.rst
%python_alternative %{_bindir}/snimpy
%python_alternative %{_mandir}/man1/snimpy.1%{ext_man}
%{python_sitearch}/snimpy
%{python_sitearch}/snimpy-%{version}.dist-info

%changelog
* Thu Nov 14 2024 Markéta Machová <mmachova@suse.com>
- Skip tests affected by too new pyasn1 for now
* Thu Jun 13 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.3:
  * Temporarily depend on pysnmp-lextudio < 6 to fix stuck SNMP
    requests.
* Fri Mar 15 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Fri Mar 15 2024 Markéta Machová <mmachova@suse.com>
- Really add dependency on pyasyncore
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Compatibility with Python 3.12 by adding dependency to
    pyasyncore.
* Tue Aug  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.1:
  * Switch to pysnmp-lextudio, a maintained fork of PySNMP.
- Drop patch python-snimpy-disable-IPv6-tests.diff, no longer required.
- Use pyproject macros.
- Stop using greedy globs in %%files.
* Wed Apr 20 2022 pgajdos@suse.com
- do not require python-mock for build
* Sun Jun  6 2021 Martin Hauke <mardnh@gmx.de>
- update to version 1.0.0:
  * Drop compatibility with Python 2
* Wed Jan 27 2021 Steve Kowalik <steven.kowalik@suse.com>
- Switch from python3_only to python_alternative for the snimpy script
  and its manual page.
* Wed Jul 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.8.14
  * Add ``items()`` in addition to ``iteritems()`` This is an iterator
    on Python 3 and return a list of items in Python 2.
  * MIB parsing is still done with ``libsmi`` but through CFFI
* Mon Mar 23 2020 Martin Hauke <mardnh@gmx.de>
- Convert to singlespec
- Update to version 0.8.13
  * Compatibility with Python 3.7.
  * Fix an issue with implied index when reusing indexes between
    tables.
- Update to version 0.8.12
  * Support for more recent versions of IPython.
  * Support for SNMPv3 context name.
  * Support for notification nodes (MIB only).
* Wed Oct 12 2016 mardnh@gmx.de
- initial package, version 0.8.11
